==> haskell-exact-pi-0.5.0.2-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-9jsj3LCWTRk8jP9uDKZ48C
key:                  exact-pi-0.5.0.2-9jsj3LCWTRk8jP9uDKZ48C
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  8be5d5566c42b0e62cce9baefdbd8eac
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-9jsj3LCWTRk8jP9uDKZ48C
depends:
    base-4.17.2.1 numtype-dk-0.5.0.3-F6qEUKEaZatXZetkjwDdM

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exact-pi-0.5.0.2-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-DXnUPYjAnTp98fVR3Wc3fg
key:                  exact-pi-0.5.0.2-DXnUPYjAnTp98fVR3Wc3fg
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  ccf72990bbd7c6caf8e4724503cd1044
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-DXnUPYjAnTp98fVR3Wc3fg
depends:
    base-4.17.2.1 numtype-dk-0.5.0.3-F6qEUKEaZatXZetkjwDdM

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
